<?php
/*
Plugin Name: PowerUp Widgets
Plugin URI: http://bonfirethemes.com/
Description: Widgets for use with the PowerUp theme.
Version: 1.0
Author: Bonfire Themes
Author URI: http://bonfirethemes.com/
License: GPL2
*/

	//
	// ENQUEUE powerup-widgets.css
	//
	function powerup_widgets_css() {
		wp_register_style( 'powerup-widgets-css', plugins_url( '/powerup-widgets.css', __FILE__ ) . '', array(), '1', 'all' );
		wp_enqueue_style( 'powerup-widgets-css' );
	}
	add_action( 'wp_enqueue_scripts', 'powerup_widgets_css' );

    //
    // Custom latest comments widget
    //
    function powerup_register_custom_comments_widget() { 
        register_widget( 'powerup_custom_comments_widget' );
    }
    add_action( 'widgets_init', 'powerup_register_custom_comments_widget' );

    class powerup_custom_comments_widget extends WP_Widget {

        public function __construct() {
            $widget_options = array( 
            'classname' => 'powerup_comment_excerpt_widget',
            'description' => 'Displays recent comments with excerpts',
            );
            parent::__construct( 'powerup_comment_excerpt_widget', 'PowerUp Recent Comments', $widget_options );
        }
        public function form( $instance ) {
            /* title */
            $title = ! empty( $instance['title'] ) ? $instance['title'] : ''; ?>
            <p>
                <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title:', 'powerup' ); ?></label>
                <input class="widefat" type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $title ); ?>" />
            </p>
            <?php
            /* comment count */
            $powerup_widget_comm_count = ! empty( $instance['powerup_widget_comm_count'] ) ? $instance['powerup_widget_comm_count'] : '';
            ?>
            <p>
                <label for="<?php echo $this->get_field_id( 'powerup_widget_comm_count' ); ?>"><?php _e( 'Number of comments to show:', 'powerup'); ?></label>
                <input class="tiny-text" id="<?php echo $this->get_field_id( 'powerup_widget_comm_count' ); ?>" name="<?php echo $this->get_field_name( 'powerup_widget_comm_count' ); ?>" type="number" value="<?php echo esc_attr( $powerup_widget_comm_count ); ?>" />
            </p>
            <?php
        }
        public function widget( $args, $instance ) {
            $title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Comments', 'powerup') : $instance['title'], $instance, $this->id_base);
            echo $args['before_widget'] . $args['before_title'] . $title . $args['after_title']; ?>
            
            <?php if ( ! empty( $instance['powerup_widget_comm_count'] ) ) {
                $comments = get_comments('status=approve&number=' . $instance['powerup_widget_comm_count'] . '');
            } else {
                $comments = get_comments('status=approve&number=5');
             } ?>
            <ul class="powerup-custom-comments-widget">
            <?php foreach ($comments as $comment) { ?>
                <li>
                    <a href="<?php echo get_permalink($comment->comment_post_ID); ?>" rel="external nofollow">
                        <div class="powerup-custom-comments-widget-wrapper">
                            <?php $title = get_the_title($comment->comment_post_ID); echo '<span class="powerup-widget-comment-author">' . ($comment->comment_author) . '</span>'; ?>
                            <span class="powerup-widget-comment-excerpt"><?php echo wp_html_excerpt( $comment->comment_content, 100 ); ?>..</span>
                            <span class="powerup-widget-comment-title"><span class="powerup-widget-comment-title-prefix"><?php esc_html_e( 'On: ', 'powerup' ); ?></span> <?php echo $title; ?></span>
                        </div>
                    </a>
                </li>
            <?php }  ?>
            </ul>

            <?php echo $args['after_widget'];
        }
        public function update( $new_instance, $old_instance ) {
            $instance = $old_instance;
            $instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
            $instance['powerup_widget_comm_count'] = ( ! empty( $new_instance['powerup_widget_comm_count'] ) ) ? strip_tags( $new_instance['powerup_widget_comm_count'] ) : '';
            return $instance;
        }
    }

    
    //
    // Custom latest comments widget
    //
    function powerup_register_recent_posts_widget() {
        register_widget( 'powerup_recent_posts_widget' );
    }
    add_action( 'widgets_init', 'powerup_register_recent_posts_widget' );

    class powerup_recent_posts_widget extends WP_Widget {

        function __construct() {
            $widget_ops = array( 'classname' => 'powerup_recent_posts_widget', 'description' => __('Displays recent posts with featured image, comment count etc.', 'powerup-widgets') );
            $control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'powerup_recent_posts_widget' );
            parent::__construct( 'powerup_recent_posts_widget', __('PowerUp Recent Posts', 'powerup-widgets'), $widget_ops, $control_ops );
        }

        // Let's display the widget
        function widget( $args, $instance ) {
            extract( $args );
            $title = apply_filters('widget_title', $instance['title'] );
            $number = $instance['number'];
            echo $before_widget;
            ?> 

            <?php
                if ( $title )
                    echo $before_title . $title . $after_title;
                ?>

                    <?php 
                    $query = new WP_Query();
                    $query->query( array(
                        'posts_per_page' => $number,
                        'ignore_sticky_posts' => 1
                    ));
                    ?>

                    <?php if ($query->have_posts()) : while ($query->have_posts()) : $query->the_post(); ?>

                        <ul>				
                            <li>
                                <!-- BEGIN COMMENT COUNT (if post has comments) -->
                                <?php if (get_comments_number()==0) { } else { ?>
                                    <div class="comment-count-bubble">
                                        <span>
                                            <?php comments_number('','1','%'); ?>
                                        </span>
                                    </div>
                                <?php } ?>
                                <!-- END COMMENT COUNT (if post has comments) -->
                                
                                <!-- BEGIN MARK HIGHLIGHTED POST -->
                                <?php if(get_theme_mod('powerup_disable_highlighted_content', '') === '') { ?>
                                    <?php if(in_category('highlighted')) { ?>
                                        <div class="highlighted-post-marker"></div>
                                    <?php } ?>
                                <?php } ?>
                                <!-- END MARK HIGHLIGHTED POST -->
                                
                                <!-- BEGIN CATEGORY MARKERS -->
                                <div class="category-markers-wrapper">
                                    <?php if(in_category('video')) { ?>
                                        <div class="video-post-marker"></div>
                                    <?php } ?>

                                    <?php if(in_category('images')) { ?>
                                        <div class="images-post-marker">
                                            <div class="images-post-marker-inner"></div>
                                        </div>
                                    <?php } ?>
                                </div>
                                <!-- END CATEGORY MARKERS -->
                                
                                <a class="powerup-latest-widget" href="<?php the_permalink(); ?>">
                                    <!-- BEGIN featured image -->
                                    <div class="featured-image">
                                        <?php if ( has_post_thumbnail() ) { ?>
                                            <?php the_post_thumbnail('powerup-widget-thumb'); ?>
                                        <?php } else { ?>
                                            <div class="no-feat-img"></div>
                                        <?php } ?>
                                    </div>
                                    <!-- END featured image -->
                                    <!-- BEGIN title + date -->
                                    <div class="powerup-latest-widget-post-title">
                                        <?php the_title(); ?>
                                    </div>
                                    <div class="powerup-latest-widget-date">
                                        <?php echo esc_attr(the_time(get_option('date_format'))); ?>
                                    </div>
                                    <!-- END title + date -->
                                </a>
                                <!-- BEGIN background line -->
                                <div class="powerup-latest-widget-bg-line"></div>
                                <!-- END background line -->
                            </li>
                        </ul> 

                    <?php endwhile; endif; ?>

                    <?php wp_reset_query(); ?>

            <?php
            echo $after_widget;
        }

        // Let's update the widget
        function update( $new_instance, $old_instance ) {
            $instance = $old_instance;
            $instance['title'] = strip_tags( $new_instance['title'] );
            $instance['number'] = strip_tags( $new_instance['number'] );
            return $instance;
        }

        // Settings & defaults
        function form( $instance ) {
            $defaults = array(
            'title' => __('','powerup-widgets'),
            'number' => 5
            );
            $instance = wp_parse_args( (array) $instance, $defaults ); ?>

            <!-- Widget title -->
            <p>
                <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'powerup-widgets') ?></label>
                <input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
            </p>
            <!-- Post count -->
            <p>
                <label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e('Number of posts to show:', 'powerup-widgets') ?></label>
                <input type="text" class="widefat" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" value="<?php echo $instance['number']; ?>" />
            </p>

        <?php
        }

    }

?>