<?php

	//
	// Titles
	//
	add_action('after_setup_theme','powerup_setup');
    function powerup_setup() {
        add_theme_support('title-tag');
    }

	//
	// Enable featured image + custom thumbnail sizes for different layouts
	//
	add_theme_support('post-thumbnails');
    /* index loop thumb */
    add_image_size('powerup-index-thumb',400,242,true);
    add_image_size('powerup-widget-thumb',200,200,true);

	//
	// Add default posts and comments RSS feed links to head
	//
	add_theme_support('automatic-feed-links');

	//
	// Styles the visual editor with editor-style.css to match the theme style
	//
	add_editor_style();

	//
	// Load theme languages
	//
	load_theme_textdomain( 'powerup', get_template_directory().'/languages' );
    
    //
    // Add custom fields to profile page
    //
    function powerup_modify_contact_methods($profile_fields) {
	    $profile_fields['position'] = 'Position';
        return $profile_fields;
    }
    add_filter('user_contactmethods', 'powerup_modify_contact_methods');
    
    //
	// Register Custom Menu Function
	//
	if (function_exists('register_nav_menus')) {
		register_nav_menus( array(
            'powerup-header-tabs' => __('PowerUp Theme: Header Tabs', 'powerup'),
			'powerup-header-dropdown' => __('PowerUp Theme: Header Dropdown Menu', 'powerup'),
            'powerup-footer' => __('PowerUp Theme: Footer Menu', 'powerup'),
		) );
	}
    
    //
	// Add the walker class (for menu descriptions)
	//
	
	class powerup_menu_description extends Walker_Nav_Menu {
		function start_el(&$output, $item, $depth = 0, $args = Array(), $id = 0) {
			global $wp_query;
			$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
			
			$class_names = $value = '';
	
			$classes = empty( $item->classes ) ? array() : (array) $item->classes;
	
			$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
			$class_names = ' class="' . esc_attr( $class_names ) . '"';
	
			$output .= $indent . '<li id="menu-item-'. $item->ID . '"' . $value . $class_names .'>';
	
			$attributes = ! empty( $item->attr_title ) ? ' title="' . esc_attr( $item->attr_title ) .'"' : '';
			$attributes .= ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) .'"' : '';
			$attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) .'"' : '';
			$attributes .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) .'"' : '';
	
			$item_output = $args->before;
			$item_output .= '<a'. $attributes .'>';
			$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
			$item_output .= '</a><div class="powerup-menu-item-description">' . $item->description . '</div>';
			$item_output .= $args->after;
	
			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args, $id );
		}
	}

	//
	// Register Widgets
	//
	function powerup_widgets_init() {
        
        register_sidebar( array(
		'name' => esc_html__( 'Front page ad spot (300x250)', 'powerup' ),
		'id' => 'powerup-index-ad-widget',
		'description' => esc_html__( 'Appears next to featured content slider (if alternate featured area layout enabled). 300x250 format, use the text widget to enter your ad code).', 'powerup' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => "</div>",
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
		));
        
        register_sidebar( array(
		'name' => esc_html__( 'Sidebar ad spot', 'powerup' ),
		'id' => 'powerup-sidebar-ad-widget',
		'description' => esc_html__( 'This widget location is intended for an ad placement (300px width format, use the text widget to enter your ad code). For standard widgets, please use the "Sidebar widgets" widget location.', 'powerup' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => "</div>",
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
		));
        
        register_sidebar( array(
		'name' => esc_html__( 'Sidebar widgets', 'powerup' ),
		'id' => 'powerup-sidebar-widgets',
		'description' => esc_html__( 'Drag widgets here', 'powerup' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => "</div>",
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
		));
        
        register_sidebar( array(
		'name' => esc_html__( 'Dropdown menu widgets', 'powerup' ),
		'id' => 'powerup-dropdown-widgets',
		'description' => esc_html__( 'This widget location is located inside the header dropdown menu.', 'powerup' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => "</div>",
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
		));
        
        register_sidebar( array(
		'name' => esc_html__( 'Footer Widgets (column 1)', 'powerup' ),
		'id' => 'powerup-footer-widgets-one',
		'description' => esc_html__( 'Drag widgets here', 'powerup' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => "</div>",
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
		));
        
        register_sidebar( array(
		'name' => esc_html__( 'Footer Widgets (column 2)', 'powerup' ),
		'id' => 'powerup-footer-widgets-two',
		'description' => esc_html__( 'Drag widgets here', 'powerup' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => "</div>",
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
		));
        
        register_sidebar( array(
		'name' => esc_html__( 'Footer Widgets (column 3)', 'powerup' ),
		'id' => 'powerup-footer-widgets-three',
		'description' => esc_html__( 'Drag widgets here', 'powerup' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => "</div>",
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
		));

	}
	add_action( 'widgets_init', 'powerup_widgets_init' );
    
    //
	// Allow Shortcodes in Text Widget
	//
	add_filter('widget_text', 'do_shortcode');

	//
	// Custom Excerpt Lengths (multiple)
	//
	function powerup_excerpt($limit) {
		$powerup_excerpt = explode(' ', get_the_excerpt(), $limit);
	if (count($powerup_excerpt)>=$limit) {
		array_pop($powerup_excerpt);
		$powerup_excerpt = implode(" ",$powerup_excerpt).' ...';
	} else {
		$powerup_excerpt = implode(" ",$powerup_excerpt);
	}
		$powerup_excerpt = preg_replace('`[[^]]*]`','',$powerup_excerpt);
		return $powerup_excerpt;
	}

	function powerup_content($limit) {
		$powerup_content = explode(' ', get_the_content(), $limit);
	if (count($powerup_content)>=$limit) {
		array_pop($powerup_content);
		$powerup_content = implode(" ",$powerup_content).'...';
	} else {
		$powerup_content = implode(" ",$powerup_content);
	}
	$powerup_content = preg_replace('/[.+]/','', $powerup_content);
	$powerup_content = apply_filters('the_content', $powerup_content);
	$powerup_content = str_replace(']]>', ']]&gt;', $powerup_content);
	return $powerup_content;
	}

    //
	// Move category and archive widget counts inside link
	//
    /* category */
    add_filter('wp_list_categories', 'powerup_cat_count_span');
    function powerup_cat_count_span($links) {
    $links = str_replace('</a> (', ' (', $links);
    $links = str_replace(')', ')</a>', $links);
    return $links;
    }
    /* archive */
    add_filter('get_archives_link', 'powerup_archive_count_span');
    function powerup_archive_count_span($links) {
    $links = str_replace('</a>&nbsp;(', ' (', $links);
    $links = str_replace(')', ')</a>', $links);
    return $links;
    }

	//
	// Default Main Nav Function
	//
	function powerup_default_main_nav() {
		echo '<ul id="main-nav" class="main-nav clearfix">';
		wp_list_pages('title_li=');
		echo '</ul>';
	}

	//
	// ENQUEUE Google WebFonts
	//
	function powerup_fonts_url() {
		$font_url = '';

		if ( 'off' !== _x( 'on', 'Google font: on or off', 'powerup' ) ) {
			$font_url = add_query_arg( 'family', urlencode( 'Roboto:400,500,700&subset=latin,latin-ext|Rajdhani:500,600,700' ), "//fonts.googleapis.com/css" );
		}
		return $font_url;
	}
	function powerup_scripts() {
		wp_enqueue_style( 'powerup-fonts', powerup_fonts_url(), array(), '1.0.0' );
	}
	add_action( 'wp_enqueue_scripts', 'powerup_scripts' );

    //
	// ENQUEUE swiper.min.css
	//
    function powerup_swiper() {
        wp_enqueue_style( 'powerup-swiper', get_template_directory_uri() . '/swiper.min.css', '1' );
	}
	add_action( 'wp_enqueue_scripts', 'powerup_swiper' );

	//
	// ENQUEUE autogrow/jquery.autogrow-textarea.js
	//
    function powerup_autogrow() {
		if ( is_singular() ) {
            wp_enqueue_script( 'powerup-autogrow', get_template_directory_uri() . '/js/autogrow/jquery.autogrow-textarea.js', '', '1', true );
		}
	}
	add_action( 'wp_enqueue_scripts', 'powerup_autogrow' );
    
    //
	// ENQUEUE jquery.scrollbar.min.js (except on touch devices)
	//
    if(get_theme_mod('powerup_disable_styled_scrollbars', '') === '') {
        function powerup_scrollbar_js() {
            wp_enqueue_script( 'powerup-scrollbar-js', get_template_directory_uri() . '/js/jquery.scrollbar.min.js', '', '1', true );
        }
        add_action( 'wp_enqueue_scripts', 'powerup_scrollbar_js' );
    }
    
    //
	// ENQUEUE scrollbar-behavior.js (except on touch devices)
	//
    if(get_theme_mod('powerup_disable_styled_scrollbars', '') === '') {
        if(get_theme_mod('powerup_disable_main_scrollbar', '') === '') {
            function powerup_scrollbar_behavior_js() {
                if ( is_admin_bar_showing() ) {
                    wp_enqueue_script( 'powerup-scrollbar-behavior-js', get_template_directory_uri() . '/js/scrollbar-behavior-admin.js', array( 'jquery' ), '1', true );
                } else {
                    wp_enqueue_script( 'powerup-scrollbar-behavior-js', get_template_directory_uri() . '/js/scrollbar-behavior.js', array( 'jquery' ), '1', true );
                }
            }
            add_action( 'wp_enqueue_scripts', 'powerup_scrollbar_behavior_js' );
        }
    }
    
    //
	// ENQUEUE swiper.min.js
	//
    function powerup_swiper_js() {
        wp_enqueue_script( 'powerup-swiper-js', get_template_directory_uri() . '/js/swiper.min.js', array( 'jquery' ), '1', true );
    }
    add_action( 'wp_enqueue_scripts', 'powerup_swiper_js' );
    
    //
	// ENQUEUE misc-footer.js
	//
    function powerup_miscfooter() {
        wp_enqueue_script( 'powerup-misc-footer', get_template_directory_uri() . '/js/misc-footer.js', array( 'jquery' ), '1', true );
	}
	add_action( 'wp_enqueue_scripts', 'powerup_miscfooter' );

	//
	// ENQUEUE comment-form.js
	//
	function powerup_commentform() {  
		if ( is_singular() ) {
		    wp_enqueue_script( 'powerup-comment-form', get_template_directory_uri() . '/js/comment-form.js', array( 'jquery' ), '1', true );
		}
	}
	add_action( 'wp_enqueue_scripts', 'powerup_commentform' );

	//
	// ENQUEUE jquery.scrollTo-min.js (smooth scrolling to anchors)
	//
    function powerup_scrollto() {
		wp_enqueue_script( 'powerup-scrollto', get_template_directory_uri() . '/js/jquery.scrollTo-min.js', array( 'jquery' ), '1', true );
	}
	add_action( 'wp_enqueue_scripts', 'powerup_scrollto' ); 

	//
	// ENQUEUE comment-reply.js (threaded comments)
	//
	function powerup_comment_reply(){
		if ( is_singular() && get_option( 'thread_comments' ) )	wp_enqueue_script( 'comment-reply' );
	}
	add_action('wp_print_scripts', 'powerup_comment_reply');

    //
	// ENQUEUE wp-toolbar-active.css (if WP toolbar active)
	//
    function powerup_wp_toolbar_active() {
        if ( is_admin_bar_showing() ) {
            wp_enqueue_style( 'powerup-wp-toolbar-active', get_template_directory_uri() . '/wp-toolbar-active.css' );
        }
    };
    add_action( 'get_footer', 'powerup_wp_toolbar_active' );
	
	//
	// Define content width
	//
	if ( ! isset( $content_width ) ) $content_width = 1000;

	//
	// Custom comment output
	//
	function powerup_custom_theme_comment($comment, $args, $depth) {
	   $GLOBALS['comment'] = $comment; 
	   ?>

		<li id="comment-<?php comment_ID() ?>" <?php comment_class(); ?>>
        
            <!-- begin comment entry -->
			<div class="comment-entry">
				<?php if ($comment->comment_approved === '0') : ?>
					<span class="awaiting-moderation"><?php esc_html_e('(Awaiting moderation.)', 'powerup') ?></span>
				<?php endif; ?>
                <?php wp_kses_post(comment_text()); ?>
                
                    <div class="comment-author-wrapper">
                        <?php echo get_avatar($comment,$size='60'); ?>
                        <div class="comment-author-inner">
                            <span class="comment-author"><?php printf(get_comment_author_link()) ?></span>
                            <span class="comment-time"><?php esc_html_e( 'on', 'powerup' ); ?> <?php comment_date('F j'); ?></span>
                            <span class="comm-divider">|</span>
                            <?php comment_reply_link(array_merge( $args, array('add_below' => 'comment', 'depth' => $depth, 'reply_text' => esc_html__( 'Reply', 'powerup' ), 'max_depth' => $args['max_depth']))) ?>
                            <?php edit_comment_link( esc_html__('Edit', 'powerup')) ?>
                        </div>
                    </div>
			</div>
            <!-- end comment entry -->
		
	<?php
	}
    
    //
	// WORDPRESS LIVE CUSTOMIZER
	//
	function powerup_theme_customizer( $wp_customize ) {
	
        //
        // ADD "powerup" PANEL TO LIVE CUSTOMIZER 
        //
        $wp_customize->add_panel('powerup_panel', array('title' => esc_html__('PowerUp Theme', 'powerup'),'priority' => 10,));       

        //
        // ADD "LOGO" SECTION TO "PowerUp Theme" PANEL 
        //
        $wp_customize->add_section('powerup_logo_section',array('title' => esc_html__( 'Logo', 'powerup' ),'panel' => 'powerup_panel','priority' => 16));
        
        /* logo image */
        $wp_customize->add_setting('powerup_logo_image', array('sanitize_callback'	=> 'sanitize_powerup_customizer_image',));
        $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'powerup_logo_image',
            array(
                'label' => __( 'Upload logo image', 'powerup' ),
                'settings' => 'powerup_logo_image',
                'section' => 'powerup_logo_section',
        )
        ));
        
        /* logo image size */
        $wp_customize->add_setting('powerup_logo_image_size', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_logo_image_size', array(
            'type' => 'text',
            'section' => 'powerup_logo_section',
            'label' => __( 'Logo image height (in pixels)', 'powerup' ),
            'description' => __( 'Set custom height for logo image. If empty, defaults to 65.', 'powerup' ),
        ));

        /* logo font size */
        $wp_customize->add_setting('powerup_logo_font_size', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_logo_font_size', array(
            'type' => 'text',
            'section' => 'powerup_logo_section',
            'label' => __( 'Logo text size (in pixels)', 'powerup' ),
            'description' => __( 'If empty, defaults to 25.', 'powerup' ),
        ));

        /* logo font color */
        $wp_customize->add_setting( 'powerup_logo_font_color', array( 'sanitize_callback' => 'sanitize_hex_color' ));
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'powerup_logo_font_color',array(
            'label' => __( 'Logo text', 'powerup' ),
            'settings' => 'powerup_logo_font_color',
            'section' => 'powerup_logo_section' )
        ));
        
        /* logo top distance */
        $wp_customize->add_setting('powerup_logo_top_distance', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_logo_top_distance', array(
            'type' => 'text',
            'section' => 'powerup_logo_section',
            'label' => __( 'Logo distance from top (in pixels)', 'powerup' ),
            'description' => __( 'If empty, logo image defaults to 20, logo text defaults to 35.', 'powerup' ),
        ));

        /* logo left distance */
        $wp_customize->add_setting('powerup_logo_left_distance', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_logo_left_distance', array(
            'type' => 'text',
            'section' => 'powerup_logo_section',
            'label' => __( 'Logo distance from left (in pixels)', 'powerup' ),
            'description' => __( 'If empty, logo image defaults to 20, logo text defaults to 30.', 'powerup' ),
        ));

        //
        // ADD "DROPDOWN MENU" SECTION TO "PowerUp Theme" PANEL 
        //
        $wp_customize->add_section('powerup_menu_dropdown_section',array('title' => esc_html__( 'Dropdown Menu', 'powerup' ),'panel' => 'powerup_panel','priority' => 16));
        
        /* menu button label */
        $wp_customize->add_setting('powerup_menu_button_label', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_menu_button_label', array(
            'type' => 'text',
            'section' => 'powerup_menu_dropdown_section',
            'label' => __( 'Menu button text label', 'powerup' ),
            'description' => __( 'If empty, defaults to "BROWSE"', 'powerup' ),
        ));

        /* menu width */
        $wp_customize->add_setting('powerup_menu_width', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_menu_width', array(
            'type' => 'text',
            'section' => 'powerup_menu_dropdown_section',
            'label' => __( 'Custom menu width (in pixels)', 'powerup' ),
            'description' => __( 'If empty, defaults to 225', 'powerup' ),
        ));

        /* menu height */
        $wp_customize->add_setting('powerup_menu_height', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_menu_height', array(
            'type' => 'text',
            'section' => 'powerup_menu_dropdown_section',
            'label' => __( 'Custom menu height (in pixels)', 'powerup' ),
            'description' => __( 'If empty, defaults to 325', 'powerup' ),
        ));

        /* dropdown menu fullscreen */
        $wp_customize->add_setting('powerup_dropdown_fullscreen', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_dropdown_fullscreen', array(
            'type' => 'text',
            'section' => 'powerup_menu_dropdown_section',
            'label' => __( 'Snap to fullscreen resolution (in pixels)', 'powerup' ),
            'description' => __( 'By default, for mobile navigation purposes, the dropdown menu will snap to fullscreen if the screen is less than 600 pixels wide. If you need to, you can change that number with this setting.', 'powerup' ),
        ));

        /* social bar label */
        $wp_customize->add_setting('powerup_social_bar_label', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_social_bar_label', array(
            'type' => 'text',
            'section' => 'powerup_menu_dropdown_section',
            'label' => __( 'Social bar text label', 'powerup' ),
            'description' => __( 'If empty, defaults to "SOCIAL:"', 'powerup' ),
        ));

        /* twitch */
        $wp_customize->add_setting('powerup_social_twitch', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_social_twitch', array(
            'type' => 'text',
            'section' => 'powerup_menu_dropdown_section',
            'label' => __( 'Twitch profile URL', 'powerup' ),
        ));

        /* youtube */
        $wp_customize->add_setting('powerup_social_youtube', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_social_youtube', array(
            'type' => 'text',
            'section' => 'powerup_menu_dropdown_section',
            'label' => __( 'YouTube profile URL', 'powerup' ),
        ));

        /* twitter */
        $wp_customize->add_setting('powerup_social_twitter', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_social_twitter', array(
            'type' => 'text',
            'section' => 'powerup_menu_dropdown_section',
            'label' => __( 'Twitter profile URL', 'powerup' ),
        ));

        /* facebook */
        $wp_customize->add_setting('powerup_social_facebook', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_social_facebook', array(
            'type' => 'text',
            'section' => 'powerup_menu_dropdown_section',
            'label' => __( 'Facebook profile URL', 'powerup' ),
        ));

        /* instagram */
        $wp_customize->add_setting('powerup_social_instagram', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_social_instagram', array(
            'type' => 'text',
            'section' => 'powerup_menu_dropdown_section',
            'label' => __( 'Instagram profile URL', 'powerup' ),
        ));

        //
        // ADD "HEADER TABS" SECTION TO "PowerUp Theme" PANEL 
        //
        $wp_customize->add_section('powerup_header_tabs_section',array('title' => esc_html__( 'Header Tabs', 'powerup' ),'panel' => 'powerup_panel','priority' => 16));
        
        /* tabs prefix */
        $wp_customize->add_setting('powerup_tabs_prefix', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_tabs_prefix', array(
            'type' => 'text',
            'section' => 'powerup_header_tabs_section',
            'label' => __( 'Tabs prefix', 'powerup' ),
            'description' => __( 'Optionally, enter a text label to be shown infront of the header tabs.', 'powerup' ),
        ));

        /* tabs marker text */
        $wp_customize->add_setting('powerup_tabs_marker', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_tabs_marker', array(
            'type' => 'text',
            'section' => 'powerup_header_tabs_section',
            'label' => __( 'Tab marker text', 'powerup' ),
            'description' => __( 'Using the menu builder, you can give a header tab the "marked" class, which will place a marker on the tab. By default, it will say "NEW" but you can use this option to have it say whatever you like.', 'powerup' ),
        ));

        /* tabs hide at resolution */
        $wp_customize->add_setting('powerup_hide_tabs', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_hide_tabs', array(
            'type' => 'text',
            'section' => 'powerup_header_tabs_section',
            'label' => __( 'Hide tabs at resolution (in pixels)', 'powerup' ),
            'description' => __( 'By default, when the screen size less 750 pixels wide the tabs are hidden for mobile navigation purposes. Depending on how many items your header has however, you may wish to change that number with this setting.', 'powerup' ),
        ));

        //
        // ADD "FEATURED & TRENDING CONTENT" SECTION TO "PowerUp Theme" PANEL
        //
        $wp_customize->add_section('powerup_featured_section',array('title' => esc_html__( 'Featured & Trending Content', 'powerup' ),'panel' => 'powerup_panel','priority' => 16));
        
        /* enable featured area on front page */
        $wp_customize->add_setting('powerup_featured_area',array('sanitize_callback' => 'sanitize_powerup_featured_area',));
        function sanitize_powerup_featured_area( $input ) { if ( $input === true ) { return 1; } else { return ''; } }
        $wp_customize->add_control('powerup_featured_area',array(
            'type' => 'checkbox',
            'label' => __( 'Enable featured area on front page', 'powerup' ),
            'description' => __( 'To make content appear in the slider, simply place posts into "Featured" category.', 'powerup' ),
            'section' => 'powerup_featured_section',
        ));
        
        /* display alternate featured area on front page */
        $wp_customize->add_setting('powerup_featured_area_alt',array('sanitize_callback' => 'sanitize_powerup_featured_area_alt',));
        function sanitize_powerup_featured_area_alt( $input ) { if ( $input === true ) { return 1; } else { return ''; } }
        $wp_customize->add_control('powerup_featured_area_alt',array(
            'type' => 'checkbox',
            'label' => __( 'Alternate featured area layout (with slider, also contains widget for an ad spot)', 'powerup' ),
            'description' => __( 'To make content appear in the slider, simply place posts into "Featured" category.', 'powerup' ),
            'section' => 'powerup_featured_section',
        ));
        
        /* disable featured slider background shape */
        $wp_customize->add_setting('powerup_disable_featured_shape',array('sanitize_callback' => 'sanitize_powerup_disable_featured_shape',));
        function sanitize_powerup_disable_featured_shape( $input ) { if ( $input === true ) { return 1; } else { return ''; } }
        $wp_customize->add_control('powerup_disable_featured_shape',array(
            'type' => 'checkbox',
            'label' => __( 'Disable featured slider animated background shape', 'powerup' ),
            'section' => 'powerup_featured_section',
        ));
        
        /* enable trending news ticker below header */
        $wp_customize->add_setting('powerup_trending_ticker',array('sanitize_callback' => 'sanitize_powerup_trending_ticker',));
        function sanitize_powerup_trending_ticker( $input ) { if ( $input === true ) { return 1; } else { return ''; } }
        $wp_customize->add_control('powerup_trending_ticker',array(
            'type' => 'checkbox',
            'label' => __( 'Enable trending ticker below header', 'powerup' ),
            'section' => 'powerup_featured_section',
        ));
        
        //
        // ADD "QUICKLINK & SEARCH" SECTION TO "PowerUp Theme" PANEL 
        //
        $wp_customize->add_section('powerup_quicklink_search_section',array('title' => esc_html__( 'Quicklink & Search', 'powerup' ),'panel' => 'powerup_panel','priority' => 16));
        
        /* quicklink label */
        $wp_customize->add_setting('powerup_quicklink_label', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_quicklink_label', array(
            'type' => 'text',
            'section' => 'powerup_quicklink_search_section',
            'label' => __( 'Quicklink label', 'powerup' ),
            'description' => __( 'Quicklink appears next to the search form in the header and provides an opportunity for a stand-out link.', 'powerup' ),
        ));

        /* quicklink URL */
        $wp_customize->add_setting('powerup_quicklink_url', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_quicklink_url', array(
            'type' => 'text',
            'section' => 'powerup_quicklink_search_section',
            'label' => __( 'Quicklink URL', 'powerup' ),
            'description' => __( 'Enter a link for the quicklink.', 'powerup' ),
        ));

        /* hide header search at resolution */
        $wp_customize->add_setting('powerup_hide_search', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_hide_search', array(
            'type' => 'text',
            'section' => 'powerup_quicklink_search_section',
            'label' => __( 'Hide search at resolution (in pixels)', 'powerup' ),
            'description' => __( 'By default, when the screen size less 960 pixels wide the search form in the header is hidden for responsive design purposes (search will then appear inside the dropdown menu instead). Depending on how you have set up your header however, you may wish to change that number with this setting.', 'powerup' ),
        ));

        //
        // ADD "MISC" SECTION TO "PowerUp Theme" PANEL 
        //
        $wp_customize->add_section('powerup_misc_section',array('title' => esc_html__( 'Misc', 'powerup' ),'panel'  => 'powerup_panel','priority' => 17));
        
        /* disable all styled scrollbars */
        $wp_customize->add_setting('powerup_disable_styled_scrollbars',array('sanitize_callback' => 'sanitize_powerup_disable_styled_scrollbars',));
        function sanitize_powerup_disable_styled_scrollbars( $input ) { if ( $input === true ) { return 1; } else { return ''; } }
        $wp_customize->add_control('powerup_disable_styled_scrollbars',array(
            'type' => 'checkbox',
            'label' => __( 'Disable all styled scrollbars', 'powerup' ),
            'description' => __( 'Note: Styled scrollbars are displayed on desktop only. On mobile, native scroll of the device is used.', 'powerup' ),
            'section' => 'powerup_misc_section',
        ));
        
        /* disable main styled scrollbar */
        $wp_customize->add_setting('powerup_disable_main_scrollbar',array('sanitize_callback' => 'sanitize_powerup_disable_main_scrollbar',));
        function sanitize_powerup_disable_main_scrollbar( $input ) { if ( $input === true ) { return 1; } else { return ''; } }
        $wp_customize->add_control('powerup_disable_main_scrollbar',array(
            'type' => 'checkbox',
            'label' => __( 'Disable main styled scrollbar', 'powerup' ),
            'description' => __( 'If ticked, the default scrollbar of a browser is used.', 'powerup' ),
            'section' => 'powerup_misc_section',
        ));
        
        /* main scrollbar color */
        $wp_customize->add_setting( 'powerup_main_scrollbar_color', array( 'sanitize_callback' => 'sanitize_hex_color' ));
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'powerup_main_scrollbar_color',array(
            'label' => __( 'Main scrollbar', 'powerup' ),
            'settings' => 'powerup_main_scrollbar_color',
            'section' => 'powerup_misc_section' )
        ));
        
        /* dropdown menu scrollbar color */
        $wp_customize->add_setting( 'powerup_dropdown_scrollbar_color', array( 'sanitize_callback' => 'sanitize_hex_color' ));
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'powerup_dropdown_scrollbar_color',array(
            'label' => __( 'Dropdown menu scrollbar', 'powerup' ),
            'settings' => 'powerup_dropdown_scrollbar_color',
            'section' => 'powerup_misc_section' )
        ));
        
        /* disable highlighted post feature */
        $wp_customize->add_setting('powerup_disable_highlighted_content',array('sanitize_callback' => 'sanitize_powerup_disable_highlighted_content',));
        function sanitize_powerup_disable_highlighted_content( $input ) { if ( $input === true ) { return 1; } else { return ''; } }
        $wp_customize->add_control('powerup_disable_highlighted_content',array(
            'type' => 'checkbox',
            'label' => __( 'Disable highlighted content feature', 'powerup' ),
            'description' => __( 'By placing content in the "Highlighted" category, you can highlight more important content on an on-going basis. If you wish to disable it however, use this option to do so.', 'powerup' ),
            'section' => 'powerup_misc_section',
        ));
        
        /* disable related stories */
        $wp_customize->add_setting('powerup_hide_related_stories',array('sanitize_callback' => 'sanitize_powerup_hide_related_stories',));
        function sanitize_powerup_hide_related_stories( $input ) { if ( $input === true ) { return 1; } else { return ''; } }
        $wp_customize->add_control('powerup_hide_related_stories',array(
            'type' => 'checkbox',
            'label' => __( 'Hide related stories', 'powerup' ),
            'description' => __( 'By default, related stories are displayed at the end of a post. To hide that area, enable this option.', 'powerup' ),
            'section' => 'powerup_misc_section',
        ));
        
        /* ad space URL */
        $wp_customize->add_setting('powerup_ad_space_url', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ));
        $wp_customize->add_control('powerup_ad_space_url', array(
            'type' => 'text',
            'section' => 'powerup_misc_section',
            'label' => __( 'Ad space URL', 'powerup' ),
            'description' => __( 'If URL entered, a link will appear next to ad spaces. Recommended usage: link to a page which outlines the advertising opportunities available on your website.', 'powerup' ),
        ));

        /* enable grouping by date */
        $wp_customize->add_setting('powerup_enable_loop_grouping',array('sanitize_callback' => 'sanitize_powerup_enable_loop_grouping',));
        function sanitize_powerup_enable_loop_grouping( $input ) { if ( $input === true ) { return 1; } else { return ''; } }
        $wp_customize->add_control('powerup_enable_loop_grouping',array(
            'type' => 'checkbox',
            'label' => __( 'Group posts by date', 'powerup' ),
            'description' => __( 'By default, latest content on the front page is all placed under the "Latest content" title. If you’d like to group your content by date instead, enable this option.', 'powerup' ),
            'section' => 'powerup_misc_section',
        ));

	}
	add_action('customize_register', 'powerup_theme_customizer');

    //
	// Sanitize customizer images
	//
    function sanitize_powerup_customizer_image( $image, $setting ) {
        $mimes = array(
            'jpg|jpeg|jpe' => 'image/jpeg',
            'gif'          => 'image/gif',
            'png'          => 'image/png',
            'bmp'          => 'image/bmp',
            'tif|tiff'     => 'image/tiff',
            'ico'          => 'image/x-icon'
        );
        $file = wp_check_filetype( $image, $mimes );
        return ( $file['ext'] ? $image : $setting->default );
    }

    //
	// ENQUEUE style.css (default WordPress stylesheet)
	//
	function powerup_style() {
        wp_enqueue_style( 'powerup-style', get_stylesheet_uri() . '', '1' );
	}
	add_action( 'wp_enqueue_scripts', 'powerup_style' );
    
    //
	// Live customizer options
	//
    function powerup_custom_styles() {

        /* logo options */
        $powerup_logo_top_distance = get_theme_mod('powerup_logo_top_distance');
        $powerup_logo_left_distance = get_theme_mod('powerup_logo_left_distance');
        $powerup_logo_font_size = get_theme_mod('powerup_logo_font_size');
        $powerup_logo_font_color = get_theme_mod('powerup_logo_font_color');
        $powerup_logo_image_size = get_theme_mod('powerup_logo_image_size');
        $custom_css = "
            .powerup-logo-wrapper img,
            .powerup-logo-wrapper span {
                top:{$powerup_logo_top_distance}px;
                left:{$powerup_logo_left_distance}px;
            }
            .powerup-logo-wrapper span {
                font-size:{$powerup_logo_font_size}px;
                color:{$powerup_logo_font_color};
            }
            .powerup-logo-wrapper img { max-height:{$powerup_logo_image_size}px; }
        ";
        wp_add_inline_style('powerup-style',$custom_css);

        /* custom dropdown menu width/height */
        $powerup_menu_width = get_theme_mod('powerup_menu_width');
        $powerup_menu_height = get_theme_mod('powerup_menu_height');
        $custom_css = "
            .powerup-by-bonfire-wrapper,
            .powerup-by-bonfire-bg-line {
                width:{$powerup_menu_width}px;
                height:{$powerup_menu_height}px;
            }
        ";
        wp_add_inline_style('powerup-style',$custom_css);

        /* custom tab marker text */
        if( get_theme_mod('powerup_tabs_marker', '') !== '') {
            $powerup_tabs_marker = get_theme_mod('powerup_tabs_marker');
            $custom_css = "
                .powerup-header-tabs-wrapper > div > ul > li.marked::before {
                    content:'{$powerup_tabs_marker}';
                }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        }
        
        /* scrollbar options */
        $powerup_main_scrollbar_color = get_theme_mod('powerup_main_scrollbar_color');
        $powerup_dropdown_scrollbar_color = get_theme_mod('powerup_dropdown_scrollbar_color');
        $custom_css = "
            .sitewrap > .scroll-element .scroll-bar { background-color:{$powerup_main_scrollbar_color}; }
            .powerup-by-bonfire > .scroll-element .scroll-bar { background-color:{$powerup_dropdown_scrollbar_color}; }
        ";
        wp_add_inline_style('powerup-style',$custom_css);

        /* index top distance (when featured area enabled and on front page) */
        if ( is_front_page() && !is_paged() && get_theme_mod('powerup_featured_area', '') !== '') {
            $custom_css = "
                .index-main-wrapper { margin-top:0; }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        }

        /* header responsive settings */
        if( get_theme_mod('powerup_hide_tabs', '') !== '') {
            $powerup_hide_tabs = get_theme_mod('powerup_hide_tabs');
            $custom_css = "
                @media screen and (max-width:{$powerup_hide_tabs}px) {
                    .powerup-header-tabs-prefix,
                    .powerup-header-tabs-wrapper { display:none; }
                    .powerup-menu-button-wrapper { margin-left:5px; margin-top:3px; }
                    .powerup-menu-tooltip:before { top:4px; }
                    .powerup-menu-active { left:13px; }
                    .powerup-main-nav-button-prefix-wrapper { background-image:none; }
                }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        } else {
            $powerup_hide_tabs = get_theme_mod('powerup_hide_tabs');
            $custom_css = "
                @media screen and (max-width:750px) {
                    .powerup-header-tabs-prefix,
                    .powerup-header-tabs-wrapper { display:none; }
                    .powerup-menu-button-wrapper { margin-left:5px; margin-top:3px; }
                    .powerup-menu-tooltip:before { top:4px; }
                    .powerup-menu-active { left:13px; }
                    .powerup-main-nav-button-prefix-wrapper { background-image:none; }
                }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        }

        /* hide search */
        if( get_theme_mod('powerup_hide_search', '') !== '') {
            $powerup_hide_search = get_theme_mod('powerup_hide_search');
            $custom_css = "
                @media screen and (max-width:{$powerup_hide_search}px) {
                    .powerup-header-search-wrapper { display:none; }
                    .powerup-menu-search-wrapper { display:block; }
                    .powerup-header-quicklink { border-right:none; top:-5px; right:0; }
                    /* if on touch device, lessen dropdown menu padding to account for lack of styled scrollbar */    
                    .powerup-by-bonfire-inner { padding-right:7px; }
                    /* fixes footer spacing issue on iOS (when not enough content to scroll) */
                    .sitewrap-inner { min-height:100%; }
                }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        } else {
            $powerup_hide_search = get_theme_mod('powerup_hide_search');
            $custom_css = "
                @media screen and (max-width:960px) {
                    .powerup-header-search-wrapper { display:none; }
                    .powerup-menu-search-wrapper { display:block; }
                    .powerup-header-quicklink { border-right:none; top:-5px; right:0; }
                    /* if on touch device, lessen dropdown menu padding to account for lack of styled scrollbar */    
                    .powerup-by-bonfire-inner { padding-right:7px; }
                    /* fixes footer spacing issue on iOS (when not enough content to scroll) */
                    .sitewrap-inner { min-height:100%; }
                }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        }

        /* drop-down menu full-screen break off point */
        if( get_theme_mod('powerup_dropdown_fullscreen', '') !== '') {
            $powerup_dropdown_fullscreen = get_theme_mod('powerup_dropdown_fullscreen');
            $custom_css = "
                @media screen and (max-width:{$powerup_dropdown_fullscreen}px) {
                    .powerup-by-bonfire-wrapper {
                        position:fixed !important;
                        top:0;
                        width:100%;
                        height:100%;
                    }
                    .powerup-by-bonfire ul li a {
                        font-size:15px;
                        line-height:22px;
                    }
                    .powerup-by-bonfire ul.sub-menu li a {
                        font-size:15px;
                        line-height:22px;
                    }
                    .powerup-by-bonfire-inner {
                        padding-top:50px;
                    }
                    .powerup-menu-active {
                        left:0;
                        right:0;
                    }
                    .powerup-menu-active .powerup-close-button { display:inline; }
                    .powerup-menu-item-description {
                        font-size:15px;
                        line-height:18px;
                    }
                    .powerup-by-bonfire ul.sub-menu li a::after,
                    .powerup-by-bonfire ul.sub-menu li.menu-item-has-children > a::after,
                    .powerup-by-bonfire ul.sub-menu li.menu-item-has-children ul li a::after,
                    .powerup-by-bonfire ul.sub-menu li.menu-item-has-children ul li:last-child a::after {
                        font-size:15px;
                    }
                    .powerup-by-bonfire ul.sub-menu li a::after,
                    .powerup-by-bonfire ul.sub-menu li.menu-item-has-children ul li:last-child a::after { right:-9px; }
                }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        } else {
            $powerup_dropdown_fullscreen = get_theme_mod('powerup_dropdown_fullscreen');
            $custom_css = "
                @media screen and (max-width:600px) {
                    .powerup-by-bonfire-wrapper {
                        position:fixed !important;
                        top:0;
                        width:100%;
                        height:100%;
                    }
                    .powerup-by-bonfire ul li a {
                        font-size:15px;
                        line-height:22px;
                    }
                    .powerup-by-bonfire ul.sub-menu li a {
                        font-size:15px;
                        line-height:22px;
                    }
                    .powerup-by-bonfire-inner {
                        padding-top:50px;
                    }
                    .powerup-menu-active {
                        left:0;
                        right:0;
                    }
                    .powerup-menu-active .powerup-close-button { display:inline; }
                    .powerup-menu-item-description {
                        font-size:15px;
                        line-height:18px;
                    }
                    .powerup-by-bonfire ul.sub-menu li a::after,
                    .powerup-by-bonfire ul.sub-menu li.menu-item-has-children > a::after,
                    .powerup-by-bonfire ul.sub-menu li.menu-item-has-children ul li a::after,
                    .powerup-by-bonfire ul.sub-menu li.menu-item-has-children ul li:last-child a::after {
                        font-size:15px;
                    }
                    .powerup-by-bonfire ul.sub-menu li a::after,
                    .powerup-by-bonfire ul.sub-menu li.menu-item-has-children ul li:last-child a::after { right:-9px; }
                }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        }

        /* reposition dropdown menu social bar if full-screen and WP toolbar active (and custom cut-off point entered) */
        if( get_theme_mod('powerup_dropdown_fullscreen', '') !== '' && is_admin_bar_showing() ) {
            $powerup_dropdown_fullscreen = get_theme_mod('powerup_dropdown_fullscreen');
            $custom_css = "
                @media screen and (max-width:{$powerup_dropdown_fullscreen}px) {
                    .powerup-social-bar-wrapper { bottom:32px; }
                    .powerup-by-bonfire-wrapper::before { bottom:81px; }
                    .powerup-by-bonfire { height:calc(100% - 81px); }
                    @media screen and (max-width:782px) {
                        .powerup-social-bar-wrapper { bottom:46px; }
                        .powerup-by-bonfire-wrapper::before { bottom:95px; }
                        .powerup-by-bonfire { height:calc(100% - 95px); }
                    }
                }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        }
        
        /* reposition dropdown menu social bar if full-screen and WP toolbar active */
        if( is_admin_bar_showing() ) {
            $powerup_dropdown_fullscreen = get_theme_mod('powerup_dropdown_fullscreen');
            $custom_css = "
                @media screen and (max-width:600px) {
                    .powerup-social-bar-wrapper { bottom:32px; }
                    .powerup-by-bonfire-wrapper::before { bottom:81px; }
                    .powerup-by-bonfire { height:calc(100% - 81px); }
                    @media screen and (max-width:782px) {
                        .powerup-social-bar-wrapper { bottom:46px; }
                        .powerup-by-bonfire-wrapper::before { bottom:95px; }
                        .powerup-by-bonfire { height:calc(100% - 95px); }
                    }
                }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        }

        /* custom tab marker text */
        if( get_theme_mod('powerup_tabs_marker', '') !== '') {
            $powerup_tabs_marker = get_theme_mod('powerup_tabs_marker');
            $custom_css = "
                .powerup-header-tabs-wrapper ul li.marked::before {
                    content:'{$powerup_tabs_marker}';
                }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        }

        /* extend front page excerpt area if no sidebar active */
        if ( !is_active_sidebar('powerup-sidebar-ad-widget') && !is_active_sidebar('powerup-sidebar-widgets') ) {
            $powerup_tabs_marker = get_theme_mod('powerup_tabs_marker');
            $custom_css = "
                .index-loop-wrapper-inner { margin-right:auto; }
            ";
            wp_add_inline_style('powerup-style',$custom_css);
        }

    }
    add_action( 'wp_enqueue_scripts', 'powerup_custom_styles' );

?>